==> nextcloud-18.0.3.tgz: nextcloud/apps/firstrunwizard/l10n/nb.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "First run wizard" : "Førstegangsveiviser",
    "Add your profile information! For example your email is needed to reset your password." : "Legg til informasjon i profilen din! For eksempel så trenger vi e-postadressen for å kunne tilbakestille passordet ditt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde og fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Legg til din profilinformasjon.Velg fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde for enklere gjenkjenning på tvers av alle funksjoner.",
    "About" : "Om",
    "Start using Nextcloud" : "Begynn å bruke Nextcloud",
    "Extend your cloud" : "Utvid skyen din",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Finn mer enn 100 apper i Nextcloud app-butikken for å tilpasse skyen din:",
    "Groupware apps like Calendar, Contacts, Mail" : "Gruppevare-apper som Kalender, Kontakter, E-post",
    "Communication with Nextcloud Talk" : "Kommunikasjon med Nextcloud Talk",
    "Collaboration apps for document editing" : "Samarbeids-apper for dokumentredigering",
    "Browse the app store" : "Bla gjennom app-butikken",
    "Stay in sync" : "Hold deg synkronisert",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud gir deg tilgang til dine filer uansett hvor du er.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Våre brukervennlige skrivebords- og mobil-klienter er tilgjengelige for alle de store plattformene uten kostnad!",
    "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
    "Desktop client" : "Skrivebordsklient",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Connect your desktop apps to %s" : "Koble dine applikasjoner til %s",
    "Connect your calendar" : "Koble til din kalender",
    "Connect your contacts" : "Koble til dine kontakter",
    "Access files via WebDAV" : "Få tilgang til filer via WebDAV",
    "Get help" : "Skaff hjelp",
    "Get more information" : "Få mer informasjon",
    "The Nextcloud documentation for home users:" : "Nextcloud-dokumentasjonen for hjemmebrukere:",
    "User manual" : "Brukermanual",
    "Admin manual" : "Administrator-manual",
    "Developer manual" : "Utviklermanual",
    "You can also ask for help in our community support channels:" : "Du kan også be om hjelp i våre støttekanaler:",
    "the Nextcloud forums" : "Nextcloud-forumene",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud sin IRC-kanal på freenode.net",
    "Start contributing" : "Begynn å bidra",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Ønsker du å få en spesifikk forbedring i Nextcloud? Fant du et problem? Vil du hjelpe med å oversette, fremme eller dokumentere Nextcloud?",
    "Become part of the Community" : "Bli en del av miljøet",
    "A safe home for all your data" : "Et trygt hjem for alle data",
    "Learn more about %s" : "Lær mer om %s",
    "Connect other apps to %s" : "Koble andre apper til %s",
    "Server address" : "Serveradresse",
    "Copy link" : "Kopier lenke",
    "Previous" : "Forrige",
    "Next" : "Neste"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.9.tgz: nextcloud/apps/firstrunwizard/l10n/nb.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "First run wizard" : "Førstegangsveiviser",
    "Add your profile information! For example your email is needed to reset your password." : "Legg til informasjon i profilen din! For eksempel så trenger vi e-postadressen for å kunne tilbakestille passordet ditt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde og fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Legg til din profilinformasjon.Velg fullt navn for enklere gjenkjenning på tvers av alle funksjoner.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Legg til din profilinformasjon. Velg et profilbilde for enklere gjenkjenning på tvers av alle funksjoner.",
    "Schedule work & meetings, synced with all your devices." : "Planlegg jobb og møter, synkronisert med alle dine enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ha dine kollegaer og venner på en plass uten å lekke deres private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app smidig integrert med Filer, Kontakter og Kalender.",
    "About" : "Om",
    "Start using Nextcloud" : "Begynn å bruke Nextcloud",
    "Extend your cloud" : "Utvid skyen din",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Finn mer enn 100 apper i Nextcloud app-butikken for å tilpasse skyen din:",
    "Groupware apps like Calendar, Contacts, Mail" : "Gruppevare-apper som Kalender, Kontakter, E-post",
    "Communication with Nextcloud Talk" : "Kommunikasjon med Nextcloud Talk",
    "Collaboration apps for document editing" : "Samarbeids-apper for dokumentredigering",
    "Browse the app store" : "Bla gjennom app-butikken",
    "Stay in sync" : "Hold deg synkronisert",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud gir deg tilgang til dine filer uansett hvor du er.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Våre brukervennlige skrivebords- og mobil-klienter er tilgjengelige for alle de store plattformene uten kostnad!",
    "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
    "Desktop client" : "Skrivebordsklient",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Connect your desktop apps to %s" : "Koble dine applikasjoner til %s",
    "Connect your calendar" : "Koble til din kalender",
    "Connect your contacts" : "Koble til dine kontakter",
    "Access files via WebDAV" : "Få tilgang til filer via WebDAV",
    "Get help" : "Skaff hjelp",
    "Get more information" : "Få mer informasjon",
    "The Nextcloud documentation for home users:" : "Nextcloud-dokumentasjonen for hjemmebrukere:",
    "User manual" : "Brukermanual",
    "Admin manual" : "Administrator-manual",
    "Developer manual" : "Utviklermanual",
    "You can also ask for help in our community support channels:" : "Du kan også be om hjelp i våre støttekanaler:",
    "the Nextcloud forums" : "Nextcloud-forumene",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud sin IRC-kanal på freenode.net",
    "Start contributing" : "Begynn å bidra",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Ønsker du å få en spesifikk forbedring i Nextcloud? Fant du et problem? Vil du hjelpe med å oversette, fremme eller dokumentere Nextcloud?",
    "Become part of the Community" : "Bli en del av miljøet",
    "A safe home for all your data" : "Et trygt hjem for alle data",
    "Learn more about %s" : "Lær mer om %s",
    "Connect other apps to %s" : "Koble andre apper til %s",
    "Server address" : "Serveradresse",
    "Copy link" : "Kopier lenke",
    "Previous" : "Forrige",
    "Next" : "Neste"
},
"nplurals=2; plural=(n != 1);");
